@@ -1,3 +1,6 @@
+
+::Version::setSubversionId {$Id: lang.tcl 11427 2009-07-30 22:42:25Z kakaroto $}
+
 if { $initialize_amsn == 1 } {
 	global lang_list langenc langlong
 	set lang_list [list]
@@ -24,7 +27,7 @@ proc scan_languages { } {
 proc detect_language { {default "en"} } {
 	global env
 	
-	if {![catch {tk windowingsystem} wsystem] && $wsystem == "aqua"} {
+	if { [OnDarwin] } {
 		if { [catch { set system_language [string tolower [exec defaults read NSGlobalDomain AppleLocale]]}]} {
 			set system_language en
 		} else {
@@ -53,8 +56,24 @@ proc detect_language { {default "en"} } {
 		return $language
 	}
 	
+	set idx [string first "." $system_language]
+	status_log "System language is $system_language\n"
+	#Remove .UTF-8 thing or similar
+	if { $idx != -1 } {
+		incr idx -1
+		set system_language [string range $system_language 0 $idx]
+		status_log "Removed . thing. Now system language is $system_language\n"
+	}
+	
+	set language [language_in_list $system_language]
+	if { $language != 0 } {
+		status_log "Matching language $language!\n"
+		return $language
+	}
+	
 	set idx [string first "_" $system_language]
-	#Remove _variant thing, like BR in pt_BR
+	# Remove _variant thing, like US in en_US
+	# This will remove _BR from pt_BR but only if it pt_BR doesn't exist in our language list.
 	if { $idx != -1 } {
 		incr idx -1
 		set system_language [string range $system_language 0 $idx]
@@ -123,7 +142,7 @@ proc trans {msg args} {
 }
 
 
-#Lectura del idioma
+#Read language file
 proc load_lang { {langcode "en"} {plugindir ""} } {
 	global lang lang_list langenc langlong
 
@@ -186,6 +205,12 @@ proc load_lang { {langcode "en"} {plugindir ""} } {
 		}
 	}
 	close $file_id
+	#load translations for BWidgets
+	if {[info exists ::BWIDGET::LIBRARY]} {
+		catch {option read [file join $::BWIDGET::LIBRARY lang ${langcode}.rc]}
+	} else {
+		catch {option read [file join utils BWidget-1.9.0 lang ${langcode}.rc]}
+	}
 	return 0
 }
 
@@ -218,7 +243,7 @@ namespace eval ::lang {
 
 		toplevel $wname
 		wm title $wname "[trans language]"
-		wm geometry $wname 300x350
+		wm geometry $wname 300x400
 		wm protocol $wname WM_DELETE_WINDOW "::lang::language_manager_close"
 
 		frame $wname.notebook -borderwidth 3
@@ -234,8 +259,8 @@ namespace eval ::lang {
 
 		set frm [$nb.nn getframe language]
 
-		frame $frm.list -class Amsn -borderwidth 0
-		frame $frm.buttons -class Amsn
+		frame $frm.list -borderwidth 0
+		frame $frm.buttons
 
 		listbox $frm.list.items -yscrollcommand "$frm.list.ys set" -font splainf \
 				-background white -relief flat -highlightthickness 0 -width 60
@@ -255,8 +280,16 @@ namespace eval ::lang {
 		pack $frm.buttons -side bottom -fill both -pady 3
 
 		foreach item $languages {
-			$frm.list.items insert end [lindex $item 0]
-		}
+			set langname [lindex $item 0]
+			set langcode [lindex $item 1]
+ 
+			$frm.list.items insert end "$langname"
+			if { $langcode == [::config::getGlobalKey language]} {
+				$frm.list.items itemconfigure end \
+					-bg [::skin::getKey extralistboxselectedbg] -fg [::skin::getKey extralistboxselected] \
+					-selectforeground [::skin::getKey extralistboxselected]
+			}
+        }
 
 
 		bind $frm.list.items <Double-Button-1> [list ::lang::show_languagechoose_Ok $languages]
@@ -280,8 +313,8 @@ namespace eval ::lang {
 		if { $::lang::LoadOk == 1 && [file writable [file join $HOME2 langlist.xml]]} {		
 
 		# Create a list box where we will put the lang
-		frame $frm.selection -class Amsn -borderwidth 0
-		listbox $frm.selection.box -yscrollcommand "$frm.selection.ys set" -font splainf -background white -relief flat -highlightthickness 0
+		frame $frm.selection -borderwidth 0
+		listbox $frm.selection.box -yscrollcommand "$frm.selection.ys set" 
 		scrollbar $frm.selection.ys -command "$frm.selection.box yview" -highlightthickness 0 -borderwidth 1 -elementborderwidth 2
 		pack $frm.selection.ys -side right -fill y
 		pack $frm.selection.box -side left -expand true -fill both
@@ -307,9 +340,15 @@ namespace eval ::lang {
 			$frm.selection.box insert end "$langname"
 			# Choose the background according to the fact lang is available or not
 			if { [lsearch $::lang::Lang $langcode] != -1 } {
-				$frm.selection.box itemconfigure end -background #DDF3FE
+				if { $langcode == [::config::getGlobalKey language]} {
+					$frm.selection.box itemconfigure end  \
+						-bg [::skin::getKey extralistboxselectedbg] -fg [::skin::getKey extralistboxselected] \
+						-selectforeground [::skin::getKey extralistboxselected]
+				}
 			} else {
-				$frm.selection.box itemconfigure end -background #FFFFFF
+				$frm.selection.box itemconfigure end \
+					-fg [::skin::getKey extrastderrcolor] \
+					-selectforeground [::skin::getKey extrastderrcolor]
 			}
 		}
 
@@ -343,7 +382,7 @@ namespace eval ::lang {
 		} else {
 
 		frame $frm.txt
-		label $frm.txt.text -text "[trans cantloadonlineversion]" -foreground red -wraplength 200
+		label $frm.txt.text -text "[trans cantloadonlineversion]" -wraplength 200
 		pack configure $frm.txt.text
 
 		frame $frm.command
@@ -405,11 +444,18 @@ namespace eval ::lang {
 		set selection [$w.selection.box curselection]
 		set langcode [lindex $::lang::OnlineLang $selection]
 		set lang "lang$langcode"
+		
+		# No selection, we shouldn't crash..
+		if {$selection == ""} {
+			return
+		}
 
 		# If the lang selected is the current lang
 		if { $langcode == [::config::getGlobalKey language]} {
 			$w.command1.load configure -state disabled -text "[trans delete]"
-			$w.txt.text configure -text "[trans currentlanguage]" -foreground red		
+			$w.txt.text configure -text "[trans currentlanguage]" \
+				-fg [::skin::getKey extrastderrcolor]
+
 		# If the file is not available
 		} elseif {[lsearch $::lang::Lang $langcode] == -1 } {
 			$w.command1.load configure -state normal -text "[trans download]" -command "[list ::lang::downloadlanguage "$langcode" $selection]"
@@ -418,6 +464,8 @@ namespace eval ::lang {
 		} elseif { ![file writable "$dir/$lang"] | $langcode == "en" } {
 			$w.command1.load configure -state disabled -text "[trans delete]"
 			$w.txt.text configure -text "[trans filenotwritable]" -foreground red
+			$w.txt.text configure -text "[trans filenotwritable]" \
+				-fg [::skin::getKey extrastderrcolor]
 		# If the file is available
 		} elseif {[lsearch $::lang::Lang $langcode] != -1 } {
 			$w.command1.load configure -state normal -text "[trans delete]" -command "[list ::lang::deletelanguage "$langcode" $selection]"
@@ -437,10 +485,18 @@ namespace eval ::lang {
 
 
 		foreach item $languages {
+			set langname [lindex $item 0]
+			set langcode [lindex $item 1]
+
+			.langchoose.notebook.nn.flanguage.list.items insert end "$langname"
+			if { $langcode == [::config::getGlobalKey language]} {
+				.langchoose.notebook.nn.flanguage.list.items itemconfigure end  \
+					-bg [::skin::getKey extralistboxselectedbg] -fg [::skin::getKey extralistboxselected] \
+					-selectforeground [::skin::getKey extralistboxselected]
+			}
+
 			.langchoose.notebook.nn.flanguage.list.items insert end [lindex $item 0]
 		}
-
-
 	}
 	
 	
@@ -539,7 +595,7 @@ namespace eval ::lang {
 	# Download the lang file
 	proc downloadlanguage { langcode { selection "" } } {
 
-		global lang_list weburl HOME2
+		global lang_list weburl
 
 		set lang "lang$langcode"
 		
@@ -556,7 +612,7 @@ namespace eval ::lang {
 
 		# Download the content of the file from the web
 		if { [catch {
-			set token [::http::geturl "http://www.amsn-project.net/autoupdater/lang/$lang" -timeout 120000 -binary 1]
+			set token [::http::geturl "$::weburl/autoupdater/lang/$lang" -timeout 120000 -binary 1]
 			set content [::http::data $token]
 			set status [::http::status $token]
 		} ] } {
@@ -596,7 +652,10 @@ namespace eval ::lang {
 
 		if { $selection != "" } {
 			catch {
-				.langchoose.notebook.nn.fmanager.selection.box itemconfigure $selection -background #DDF3FE
+				.langchoose.notebook.nn.fmanager.selection.box itemconfigure $selection \
+					-fg [::skin::getKey extrastdtxtcolor] \
+					-selectforeground [::skin::getKey extraselectedtxtcolor]
+
 				::lang::language_manager_selected
 			}
 		}
@@ -739,6 +798,9 @@ namespace eval ::lang {
 	# Add a new lang
 
 	proc AddLang { langcode name version encoding } {
+		if {$langcode == "" } {
+			return
+		}
 
 		array set ::lang::Lang$langcode [list name "$name" version $version encoding $encoding]
 
@@ -805,7 +867,7 @@ namespace eval ::lang {
 			set filename "[file join $HOME2 langlistnew.xml]"
 
 			set fid [open $filename w]
-			set token [::http::geturl "http://www.amsn-project.net/autoupdater/langlist" -timeout 120000 -binary 1]
+			set token [::http::geturl "$::weburl/autoupdater/langlist" -timeout 120000 -binary 1]
 			set content [::http::data $token]
 			fconfigure $fid -encoding binary
 			puts -nonewline $fid "$content"
